Learn R Programming

DBModelSelect (version 0.2.0)

DBModelSelect-package: tools:::Rd_package_title("DBModelSelect")

Description

tools:::Rd_package_description("DBModelSelect")

Arguments

Author

Maintainer: Scott H. Koeneman Scott.Koeneman@jefferson.edu

Details

The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("DBModelSelect") tools:::Rd_package_indices("DBModelSelect") The DBModelSelect package provides several methods of model selection based in distributional theory. This includes an implementation of selection using standardized information criteria in the StandICModelSelect function, and the implementation of an omnibus goodness-of-fit test for linear models in the BootGOFTestLM function.

See Also